@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2006-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -26,9 +26,10 @@
 #include <dbus/dbus-glib-lowlevel.h>
 #include <glib/gi18n.h>
 #include <string.h>
+#include <libdbus-monitor-session.h>
+
 #include "gpm-inhibit.h"
 #include "gpm-debug.h"
-#include "gpm-dbus-monitor.h"
 #include "gpm-conf.h"
 
 static void     gpm_inhibit_class_init (GpmInhibitClass *klass);
@@ -48,13 +49,34 @@ typedef struct
 struct GpmInhibitPrivate
 {
 	GSList			*list;
-	GpmDbusMonitor		*dbus_monitor;
+	DbusMonitorSession	*dbus_monitor;
 	GpmConf			*conf;
 	gboolean		 ignore_inhibits;
 };
 
+enum {
+	HAS_INHIBIT_CHANGED,
+	LAST_SIGNAL
+};
+
+static guint	     signals [LAST_SIGNAL] = { 0, };
+
 G_DEFINE_TYPE (GpmInhibit, gpm_inhibit, G_TYPE_OBJECT)
 
+/**
+ * gpm_inhibit_error_quark:
+ * Return value: Our personal error quark.
+ **/
+GQuark
+gpm_inhibit_error_quark (void)
+{
+	static GQuark quark = 0;
+	if (!quark) {
+		quark = g_quark_from_static_string ("gpm_inhibit_error");
+	}
+	return quark;
+}
+
 /**
  * gpm_inhibit_cookie_compare_func
  * @a: Pointer to the data to test
@@ -90,9 +112,10 @@ gpm_inhibit_find_cookie (GpmInhibit *inhibit, guint32 cookie)
 {
 	GpmInhibitData *data;
 	GSList	       *ret;
+	/* search list */
 	ret = g_slist_find_custom (inhibit->priv->list, &cookie,
 				   gpm_inhibit_cookie_compare_func);
-	if (! ret) {
+	if (ret == NULL) {
 		return NULL;
 	}
 	data = (GpmInhibitData *) ret->data;
@@ -120,7 +143,7 @@ gpm_inhibit_generate_cookie (GpmInhibit *inhibit)
 }
 
 /**
- * gpm_inhibit_request_cookie:
+ * gpm_inhibit_inhibit:
  * @connection: Connection name, e.g. ":0.13"
  * @application:	Application name, e.g. "Nautilus"
  * @reason: Reason for inhibiting, e.g. "Copying files"
@@ -133,11 +156,11 @@ gpm_inhibit_generate_cookie (GpmInhibit *inhibit)
  * Return value: a new random cookie.
  **/
 void
-gpm_inhibit_request_cookie (GpmInhibit	*inhibit,
-			    const gchar *application,
-			    const gchar *reason,
-			    DBusGMethodInvocation *context,
-			    GError	**error)
+gpm_inhibit_inhibit (GpmInhibit  *inhibit,
+		          const gchar *application,
+		          const gchar *reason,
+		          DBusGMethodInvocation *context,
+		          GError     **error)
 {
 	const gchar *connection;
 	GpmInhibitData *data;
@@ -162,12 +185,16 @@ gpm_inhibit_request_cookie (GpmInhibit	*inhibit,
 	data->connection = g_strdup (connection);
 	data->reason = g_strdup (reason);
 
-	inhibit->priv->list = g_slist_append (inhibit->priv->list,
-					      (gpointer) data);
+	inhibit->priv->list = g_slist_append (inhibit->priv->list, (gpointer) data);
 
 	gpm_debug ("Recieved Inhibit from '%s' (%s) because '%s' saving as #%i",
 		   data->application, data->connection, data->reason, data->cookie);
 
+	/* only emit event on the first one */
+	if (g_slist_length (inhibit->priv->list) == 1) {
+		g_signal_emit (inhibit, signals [HAS_INHIBIT_CHANGED], 0, TRUE);
+	}
+
 	dbus_g_method_return (context, data->cookie);
 }
 
@@ -182,30 +209,39 @@ gpm_inhibit_free_data_object (GpmInhibitData *data)
 }
 
 /**
- * gpm_inhibit_clear_cookie:
+ * gpm_inhibit_un_inhibit:
  * @application:	Application name
  * @cookie: The cookie that we used to register
  *
  * Removes a cookie and associated data from the GpmInhibitData struct.
  **/
 gboolean
-gpm_inhibit_clear_cookie (GpmInhibit  *inhibit,
-		          guint32      cookie,
-		          GError     **error)
+gpm_inhibit_un_inhibit (GpmInhibit  *inhibit,
+		        guint32      cookie,
+		        GError     **error)
 {
 	GpmInhibitData *data;
 
 	/* Only remove the correct cookie */
 	data = gpm_inhibit_find_cookie (inhibit, cookie);
 	if (data == NULL) {
-		gpm_warning ("Cannot find registered program for #%i, so "
-			     "cannot do UnInhibit", cookie);
+		*error = g_error_new (gpm_inhibit_error_quark (),
+				      GPM_INHIBIT_ERROR_GENERAL,
+				      "Cannot find registered program for #%i, so "
+				      "cannot do UnInhibit!", cookie);
 		return FALSE;
 	}
 	gpm_debug ("UnInhibit okay #%i", cookie);
 	gpm_inhibit_free_data_object (data);
-	inhibit->priv->list = g_slist_remove (inhibit->priv->list,
-					      (gconstpointer) data);
+
+	/* remove it from the list */
+	inhibit->priv->list = g_slist_remove (inhibit->priv->list, (gconstpointer) data);
+
+	/* only emit event on the last one */
+	if (g_slist_length (inhibit->priv->list) == 0) {
+		g_signal_emit (inhibit, signals [HAS_INHIBIT_CHANGED], 0, FALSE);
+	}
+
 	return TRUE;
 }
 
@@ -245,8 +281,8 @@ gpm_inhibit_remove_dbus (GpmInhibit  *inhibit,
 			gpm_debug ("Auto-revoked idle inhibit on '%s'.",
 				   data->application);
 			gpm_inhibit_free_data_object (data);
-			inhibit->priv->list = g_slist_remove (inhibit->priv->list,
-							      (gconstpointer) data);
+			/* remove it from the list */
+			inhibit->priv->list = g_slist_remove (inhibit->priv->list, (gconstpointer) data);
 		}
 	}
 	return;
@@ -263,7 +299,7 @@ gpm_inhibit_remove_dbus (GpmInhibit  *inhibit,
  * The noc session DBUS callback.
  **/
 static void
-dbus_noc_session_cb (GpmDbusMonitor *dbus_monitor,
+dbus_noc_session_cb (DbusMonitorSession *dbus_monitor,
 		     const gchar    *name,
 		     const gchar    *prev,
 		     const gchar    *new,
@@ -275,45 +311,40 @@ dbus_noc_session_cb (GpmDbusMonitor *dbus_monitor,
 }
 
 /**
- * gpm_inhibit_is_valid
+ * gpm_inhibit_has_inhibit
  *
  * Checks to see if we are being stopped from performing an action.
  *
  * TRUE if the action is OK, i.e. we have *not* been inhibited.
  **/
 gboolean
-gpm_inhibit_is_valid (GpmInhibit *inhibit,
-		      gboolean   *valid,
-		      GError    **error)
+gpm_inhibit_has_inhibit (GpmInhibit *inhibit,
+		         gboolean   *has_inihibit,
+		         GError    **error)
 {
+	guint length;
+
+	length = g_slist_length (inhibit->priv->list);
 
 	if (inhibit->priv->ignore_inhibits == TRUE) {
 		gpm_debug ("Inhibit ignored through gconf policy!");
-		*valid = TRUE;
-	} else if (g_slist_length (inhibit->priv->list) == 0) {
+		*has_inihibit = FALSE;
+	}
+
+	/* An inhibit can stop the action */
+	if (length == 0) {
 		gpm_debug ("Valid as no inhibitors");
-		*valid = TRUE;
+		*has_inihibit = FALSE;
 	} else {
 		/* we have at least one application blocking the action */
-		gpm_debug ("We have valid inhibitors");
-		*valid = FALSE;
+		gpm_debug ("We have %i valid inhibitors", length);
+		*has_inihibit = TRUE;
 	}
+
 	/* we always return successful for DBUS */
 	return TRUE;
 }
 
-/**
- * gpm_inhibit_check:
- * Return value: TRUE if the action is OK, i.e. we have *not* been inhibited
- **/
-gboolean
-gpm_inhibit_check (GpmInhibit *inhibit)
-{
-	gboolean valid;
-	gpm_inhibit_is_valid (inhibit, &valid, NULL);
-	return valid;
-}
-
 /**
  * gpm_inhibit_get_message:
  *
@@ -375,6 +406,13 @@ gpm_inhibit_class_init (GpmInhibitClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = gpm_inhibit_finalize;
+
+	signals [HAS_INHIBIT_CHANGED] =
+		g_signal_new ("has-inhibit-changed",
+			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GpmInhibitClass, has_inhibit_changed),
+			      NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN,
+			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 	g_type_class_add_private (klass, sizeof (GpmInhibitPrivate));
 }
 
@@ -384,8 +422,8 @@ gpm_inhibit_init (GpmInhibit *inhibit)
 {
 	inhibit->priv = GPM_INHIBIT_GET_PRIVATE (inhibit);
 	inhibit->priv->list = NULL;
-	inhibit->priv->dbus_monitor = gpm_dbus_monitor_new ();
-	g_signal_connect (inhibit->priv->dbus_monitor, "noc-session",
+	inhibit->priv->dbus_monitor = dbus_monitor_session_new ();
+	g_signal_connect (inhibit->priv->dbus_monitor, "name-owner-changed",
 			  G_CALLBACK (dbus_noc_session_cb), inhibit);
 
 	inhibit->priv->conf = gpm_conf_new ();
@@ -410,7 +448,6 @@ gpm_inhibit_finalize (GObject *object)
 	inhibit = GPM_INHIBIT (object);
 	inhibit->priv = GPM_INHIBIT_GET_PRIVATE (inhibit);
 
-	/* remove items in list and free */
 	for (a=0; a<g_slist_length (inhibit->priv->list); a++) {
 		data = (GpmInhibitData *) g_slist_nth_data (inhibit->priv->list, a);
 		gpm_inhibit_free_data_object (data);
