@@ -61,7 +61,10 @@ gpm_st_cell (GpmSelfTest *test)
 	gchar *desc;
 	gboolean ret;
 	gchar *udi;
-	test->type = "GpmCell          ";
+
+	if (gpm_st_start (test, "GpmCell", CLASS_AUTO) == FALSE) {
+		return;
+	}
 
 	/* get battery */
 	udi = gpm_cell_get_battery ();
@@ -94,6 +97,7 @@ gpm_st_cell (GpmSelfTest *test)
 	desc = gpm_cell_get_description (cell);
 	if (desc != NULL) {
 		gpm_st_success (test, "got description %s", desc);
+		g_free (desc);
 	} else {
 		gpm_st_failed (test, "could not get description");
 	}
@@ -120,6 +124,7 @@ gpm_st_cell (GpmSelfTest *test)
 	desc = gpm_cell_get_description (cell);
 	if (desc != NULL) {
 		gpm_st_success (test, "got description %s", desc);
+		g_free (desc);
 	} else {
 		gpm_st_failed (test, "could not get description");
 	}
@@ -144,5 +149,7 @@ gpm_st_cell (GpmSelfTest *test)
 
 	g_free (udi);
 	g_object_unref (cell);
+
+	gpm_st_end (test);
 }
 
